CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_distances.py File Reference

CCL

Namespaces | Functions | Variables
ccl_test_distances.py File Reference

## Namespaces
| ccl_test_distances

## Functions
def | ccl_test_distances.read_chi_test_file ()
def | ccl_test_distances.read_dm_test_file ()
def | ccl_test_distances.compare_distances (z, chi_bench, dm_bench, Omega_v, w0, wa)
def | ccl_test_distances.test_distance_model_0 ()
def | ccl_test_distances.test_distance_model_1 ()
def | ccl_test_distances.test_distance_model_2 ()
def | ccl_test_distances.test_distance_model_3 ()
def | ccl_test_distances.test_distance_model_4 ()

## Variables
int | ccl_test_distances.DISTANCES_TOLERANCE = 1e-4
float | ccl_test_distances.Omega_c = 0.25
float | ccl_test_distances.Omega_b = 0.05
int | ccl_test_distances.N_nu_rel = 0.
float | ccl_test_distances.h = 0.7
float | ccl_test_distances.A_s = 2.1e-9
float | ccl_test_distances.n_s = 0.96
| ccl_test_distances.Omega_v_vals = np.array([0.7, 0.7, 0.7, 0.65, 0.75])
| ccl_test_distances.w0_vals = np.array([-1.0, -0.9, -0.9, -0.9, -0.9])
| ccl_test_distances.wa_vals = np.array([0.0, 0.0, 0.1, 0.1, 0.1])